pub trait ErrorHandler<T, E> {
// Required method
fn handle_err(self, loc: Location) -> Result<T, Error>;
}Expand description
Trait for logging and handling errors in a unified way
pub trait ErrorHandler<T, E> {
// Required method
fn handle_err(self, loc: Location) -> Result<T, Error>;
}Trait for logging and handling errors in a unified way